@@ -34,8 +34,6 @@ labkey.deleteRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, t
 
     ## URL encode folder path, JSON encode post body (if not already encoded)
     toDelete <- convertFactorsToStrings(toDelete);
-    nrows <- nrow(toDelete)
-    ncols <- ncol(toDelete)
 
     params <- list(schemaName=schemaName, queryName=queryName, apiVersion=8.3)
     if (!missing(provenanceParams))
@@ -43,18 +41,7 @@ labkey.deleteRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, t
     if (!missing(options))
         params <- c(params, options)
 
-    p1 <- toJSON(params, auto_unbox=TRUE)
-    cnames <- colnames(toDelete)
-    p3 <- NULL
-    for(j in 1:nrows)
-    {
-        cvalues <- as.list(toDelete[j,])
-        names(cvalues) <- cnames
-        p2 <- toJSON(cvalues, auto_unbox=TRUE)
-        p3 <- c(p3, p2)
-    }
-    p3 <- paste(p3, collapse=",")
-    pbody <- paste(substr(p1, 1, nchar(p1) - 1),', \"rows\":[',p3,"] }",sep="")
+    pbody <- jsonEncodeRowsAndParams(toDelete, params, NULL)
 
     myurl <- paste(baseUrl, "query", folderPath, "deleteRows.api", sep="")
 
